@@ -475,7 +475,6 @@ sub evt_process_exit {
       copy "cmds_saved.template", "cmds.txt";
       my $iptext=$self->{ip_txt};
       $set_shifted_flag=1;
-print "WHAT IS THISSSSS=$self->{ppk_file}\n";
       my $proc=Wx::Perl::ProcessStream::Process->new(
             "runputty \'$self->{ppk_file}\' $iptext",'putty',$self);
       $self->{shifted_cmds}=$proc;
@@ -562,9 +561,7 @@ sub fullauto_button {
       $ver=~s/^.*(Version.*)$/$1/s;
       $ver=~s/^Version (10).*$/$1/;
       $ver=~s/\s//sg;
-print "VERRR=$ver<==\n";
       $ver=0 unless $ver=~/10/;
-print "VERSION=$ver\n";
       unless (-e "$keybasename.ppk") {
          Wx::ExecuteCommand("puttykey \"$keybasename\" $path $ver",wxEXEC_SYNC);
       }
@@ -621,7 +618,7 @@ print "VERSION=$ver\n";
    print FH $self->{fp2}->GetPath()."\n";
    print FH "TagFA=".$self->{tagged}."\n";
    close FH;
-print "GOING TO RUNPUTTY\n";
+print "GOING TO RUNPUTTY: runputty \"$self->{ppk_file}\" $iptext\n";
    my $proc1=Wx::Perl::ProcessStream::Process->new(
          "runputty \"$self->{ppk_file}\" $iptext",'putty',$self);
    $proc1->Run;
