@@ -299,7 +299,7 @@ sub launch_server {
    my $tag=$_[6]||'';
    my $num=$cnt+1;
    my ($server_host_block,$handle,$hash,$output,$error,$inst)=('','','','','');
-   foreach (0..2) {
+   foreach my $count (0..2) {
       ($server_host_block,$inst)=launch_instance(
          $launch_cmd,$server_type,$cnt,$num,$username);
       my $iset=$Net::FullAuto::ISets->{selected_iset};
@@ -318,7 +318,8 @@ sub launch_server {
          my $stderr=$error;
          my $t="aws ec2 terminate-instances --instance-id $inst->{InstanceId}";
          ($hash,$output,$error)=run_aws_cmd($t);
-         &exit_on_error($stderr);
+         &exit_on_error($stderr) if $count>1;
+         next;
       }
       last;
    }
